@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 from . import __version__, __app_name__, logger
-from .config import read_config, app as config_app, get_creds
+from .config import read_config, app as config_app, get_config
 from .types import OnOffToggleEnum
 from .utils import (
     bool2color,
@@ -39,20 +39,23 @@ app = typer.Typer(name="script")
 
 
 async def get_scripts():
-    async with SurgeAPIClient(*get_creds()) as client:
+    async with SurgeAPIClient(*get_config()) as client:
         scripting_resp = await client.get_scripts()
         return await scripting_resp.json()
 
 
-@app.callback()
-def scripts():
+@app.callback(invoke_without_command=True)
+def scripts(ctx: typer.Context, output_json: bool = typer.Option(False, "--json", '-j'), pretty_print: bool = typer.Option(False, "--pretty", "-p"), rich_print: bool = typer.Option(False, "--rich", "-r")):
+    """Get all scripts"""
+    if ctx.invoked_subcommand is not None:
+        return
     scripts_resp = asyncio.run(get_scripts())
-    typer_output_dict(scripts_resp)
+    typer_output_dict(scripts_resp, output_json, pretty_print, rich_print)
 
 
 async def eval_script_mock(**kwargs):
     req = EvalScriptMockRequest(**kwargs)
-    async with SurgeAPIClient(*get_creds()) as client:
+    async with SurgeAPIClient(*get_config()) as client:
         eval_script_mock_resp = await client.eval_script_mock(req)
         return await eval_script_mock_resp.json()
 
